@@ -21,9 +21,9 @@
 #include "timezonemodel.h"
 #include "timezonesi18n.h"
 
-#include <QTimeZone>
-#include <QStringMatcher>
 #include <KLocalizedString>
+#include <QStringMatcher>
+#include <QTimeZone>
 
 TimeZoneFilterProxy::TimeZoneFilterProxy(QObject *parent)
     : QSortFilterProxyModel(parent)
@@ -33,16 +33,20 @@ TimeZoneFilterProxy::TimeZoneFilterProxy(QObject *parent)
 
 bool TimeZoneFilterProxy::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
-    if (!sourceModel() || m_filterString.isEmpty()) {
+    if (!sourceModel() || (m_filterString.isEmpty() && !m_onlyShowChecked)) {
         return true;
     }
 
+    const bool checked = sourceModel()->index(source_row, 0, source_parent).data(TimeZoneModel::CheckedRole).toBool();
+    if (m_onlyShowChecked && !checked) {
+        return false;
+    }
+
     const QString city = sourceModel()->index(source_row, 0, source_parent).data(TimeZoneModel::CityRole).toString();
     const QString region = sourceModel()->index(source_row, 0, source_parent).data(TimeZoneModel::RegionRole).toString();
     const QString comment = sourceModel()->index(source_row, 0, source_parent).data(TimeZoneModel::CommentRole).toString();
 
-    if (m_stringMatcher.indexIn(city) != -1 || m_stringMatcher.indexIn(region) != -1 ||
-        m_stringMatcher.indexIn(comment) != -1) {
+    if (m_stringMatcher.indexIn(city) != -1 || m_stringMatcher.indexIn(region) != -1 || m_stringMatcher.indexIn(comment) != -1) {
         return true;
     }
 
@@ -57,11 +61,20 @@ void TimeZoneFilterProxy::setFilterString(const QString &filterString)
     invalidateFilter();
 }
 
+void TimeZoneFilterProxy::setOnlyShowChecked(const bool show)
+{
+    if (m_onlyShowChecked == show) {
+        return;
+    }
+    m_onlyShowChecked = show;
+    emit onlyShowCheckedChanged();
+}
+
 //=============================================================================
 
 TimeZoneModel::TimeZoneModel(QObject *parent)
-    : QAbstractListModel(parent),
-      m_timezonesI18n(new TimezonesI18n(this))
+    : QAbstractListModel(parent)
+    , m_timezonesI18n(new TimezonesI18n(this))
 {
     update();
 }
@@ -81,7 +94,7 @@ QVariant TimeZoneModel::data(const QModelIndex &index, int role) const
     if (index.isValid()) {
         TimeZoneData currentData = m_data.at(index.row());
 
-        switch(role) {
+        switch (role) {
         case TimeZoneIdRole:
             return currentData.id;
         case RegionRole:
@@ -92,6 +105,8 @@ QVariant TimeZoneModel::data(const QModelIndex &index, int role) const
             return currentData.comment;
         case CheckedRole:
             return currentData.checked;
+        case IsLocalTimeZoneRole:
+            return currentData.isLocalTimeZone;
         }
     }
 
@@ -134,10 +149,11 @@ void TimeZoneModel::update()
     const QStringList data = QString::fromUtf8(localZone.id()).split(QLatin1Char('/'));
 
     TimeZoneData local;
+    local.isLocalTimeZone = true;
     local.id = QStringLiteral("Local");
     local.region = i18nc("This means \"Local Timezone\"", "Local");
     local.city = m_timezonesI18n->i18nCity(data.last());
-    local.comment = i18n("Your system time zone");
+    local.comment = i18n("System's local time zone");
     local.checked = false;
 
     m_data.append(local);
@@ -152,16 +168,14 @@ void TimeZoneModel::update()
         const QStringList splitted = QString::fromUtf8(zone.id()).split(QStringLiteral("/"));
 
         // CITY | COUNTRY | CONTINENT
-        const QString key = QStringLiteral("%1|%2|%3").arg(splitted.last(),
-                                                    QLocale::countryToString(zone.country()),
-                                                    splitted.first());
+        const QString key = QStringLiteral("%1|%2|%3").arg(splitted.last(), QLocale::countryToString(zone.country()), splitted.first());
 
         cities.append(key);
         zonesByCity.insert(key, zone);
     }
     cities.sort(Qt::CaseInsensitive);
 
-    Q_FOREACH (const QString &key, cities) {
+    for (const QString &key : qAsConst(cities)) {
         const QTimeZone timeZone = zonesByCity.value(key);
         QString comment = timeZone.comment();
 
@@ -172,9 +186,11 @@ void TimeZoneModel::update()
         const QStringList cityCountryContinent = key.split(QLatin1Char('|'));
 
         TimeZoneData newData;
+        newData.isLocalTimeZone = false;
         newData.id = timeZone.id();
-        newData.region = timeZone.country() == QLocale::AnyCountry ? QString()
-                                                                   : m_timezonesI18n->i18nContinents(cityCountryContinent.at(2)) + QLatin1Char('/') + m_timezonesI18n->i18nCountry(timeZone.country());
+        newData.region = timeZone.country() == QLocale::AnyCountry
+            ? QString()
+            : m_timezonesI18n->i18nContinents(cityCountryContinent.at(2)) + QLatin1Char('/') + m_timezonesI18n->i18nCountry(timeZone.country());
         newData.city = m_timezonesI18n->i18nCity(cityCountryContinent.at(0));
         newData.comment = comment;
         newData.checked = false;
@@ -219,14 +235,14 @@ QHash<int, QByteArray> TimeZoneModel::roleNames() const
         {RegionRole, "region"},
         {CityRole, "city"},
         {CommentRole, "comment"},
-        {CheckedRole, "checked"}
+        {CheckedRole, "checked"},
+        {IsLocalTimeZoneRole, "isLocalTimeZone"},
     });
 }
 
 void TimeZoneModel::sortTimeZones()
 {
-    std::sort(m_selectedTimeZones.begin(), m_selectedTimeZones.end(),
-              [this](const QString &a, const QString &b) {
-                  return m_offsetData.value(a) < m_offsetData.value(b);
-              });
+    std::sort(m_selectedTimeZones.begin(), m_selectedTimeZones.end(), [this](const QString &a, const QString &b) {
+        return m_offsetData.value(a) < m_offsetData.value(b);
+    });
 }
